@@ -9,10 +9,10 @@ import time
 def main(args):
     dev = libevdev.Device()
     dev.name = "test device"
-    dev.enable(libevdev.EV_REL.REL_X)
-    dev.enable(libevdev.EV_REL.REL_Y)
-    dev.enable(libevdev.EV_KEY.BTN_LEFT)
-    dev.enable(libevdev.EV_KEY.BTN_RIGHT)
+    dev.enable(libevdev.REL_X)
+    dev.enable(libevdev.REL_Y)
+    dev.enable(libevdev.BTN_LEFT)
+    dev.enable(libevdev.BTN_RIGHT)
     try:
         uinput = dev.create_uinput_device()
         print("New device at {} ({})".format(uinput.devnode, uinput.syspath))
@@ -24,9 +24,11 @@ def main(args):
         time.sleep(1)
 
         for _ in range(5):
-            events = [InputEvent(libevdev.EV_REL.REL_X, -1),
-                      InputEvent(libevdev.EV_REL.REL_Y, 1),
-                      InputEvent(libevdev.EV_SYN.SYN_REPORT, 0)]
+            events = [
+                InputEvent(libevdev.REL_X, -1),
+                InputEvent(libevdev.REL_Y, 1),
+                InputEvent(libevdev.SYN_REPORT, 0),
+            ]
             time.sleep(0.012)
             uinput.send_events(events)
     except OSError as e:
